@@ -1,21 +1,16 @@
 /*
- * ModSecurity for Apache 2.x, http://www.modsecurity.org/
- * Copyright (c) 2004-2010 Trustwave Holdings, Inc. (http://www.trustwave.com/)
- *
- * This product is released under the terms of the General Public Licence,
- * version 2 (GPLv2). Please refer to the file LICENSE (included with this
- * distribution) which contains the complete text of the licence.
- *
- * There are special exceptions to the terms and conditions of the GPL
- * as it is applied to this software. View the full text of the exception in
- * file MODSECURITY_LICENSING_EXCEPTION in the directory of this software
- * distribution.
- *
- * If any of the files related to licensing are missing or if you have any
- * other questions related to licensing please contact Trustwave Holdings, Inc.
- * directly using the email address support@trustwave.com.
- *
- */
+* ModSecurity for Apache 2.x, http://www.modsecurity.org/
+* Copyright (c) 2004-2011 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+*
+* You may not use this file except in compliance with
+* the License.  You may obtain a copy of the License at
+*
+*     http://www.apache.org/licenses/LICENSE-2.0
+*
+* If any of the files related to licensing are missing or if you have any
+* other questions related to licensing please contact Trustwave Holdings, Inc.
+* directly using the email address security@modsecurity.org.
+*/
 
 /* Aho-Corasick Matching  */
 
@@ -42,9 +37,9 @@
  * Data structures for acmp parser
  */
 
- /**
-  * One node in trie
-  */
+/**
+ * One node in trie
+ */
 typedef struct acmp_node_t acmp_node_t;
 typedef struct acmp_btree_node_t acmp_btree_node_t;
 struct acmp_node_t {
@@ -79,9 +74,9 @@ struct acmp_btree_node_t {
  * Data related to parser, not to individual nodes
  */
 struct ACMP {
-    #ifdef ACMP_USE_UTF8
+#ifdef ACMP_USE_UTF8
     int is_utf8;
-    #endif
+#endif
     int is_case_sensitive;
     apr_pool_t *parent_pool;
     apr_pool_t *pool;
@@ -188,11 +183,11 @@ static long utf8_lcase(acmp_utf8_char_t ucs_code) {
  * Returns length of given string for parser's encoding
  */
 static size_t acmp_strlen(ACMP *parser, const char *str) {
-    #ifdef ACMP_USE_UTF8
+#ifdef ACMP_USE_UTF8
     return (parser->is_utf8 == 0) ? strlen(str) : utf8_strlen(str);
-    #else
+#else
     return strlen(str);
-    #endif
+#endif
 }
 
 /**
@@ -205,14 +200,14 @@ static void acmp_strtoucs(ACMP *parser, const char *str, acmp_utf8_char_t *ucs_c
     int i;
     const char *c = str;
 
-    #ifdef ACMP_USE_UTF8
+#ifdef ACMP_USE_UTF8
     if (parser->is_utf8) {
         for (i = 0; i < len; i++) {
             *(ucs_chars++) = utf8_decodechar(c);
             c += utf8_seq_len(c);
         }
     } else
-    #endif
+#endif
     {
         for (i = 0; i < len; i++) {
             *(ucs_chars++) = *(c++);
@@ -268,33 +263,6 @@ static void acmp_clone_node_no_state(acmp_node_t *from, acmp_node_t *to) {
     to->hit_count = 0;
 }
 
-/**
- * Copies sibling nodes and child node for from given "from" node to "to" node.
- *   Both nodes must already exist.
- */
-static void acmp_copy_nodes_recursive(acmp_node_t *from, acmp_node_t *to, apr_pool_t *pool) {
-    acmp_node_t *old_node = from->child, *new_node, *nn2;
-    if (old_node == NULL) return;
-    nn2 = apr_pcalloc(pool, sizeof(acmp_node_t));
-    /* ENH: Check alloc succeded */
-    acmp_clone_node_no_state(old_node, nn2);
-    nn2->parent = to;
-    to->child = nn2;
-    acmp_copy_nodes_recursive(from->child, to->child, pool);
-
-    for (;;) {
-        old_node = old_node->sibling;
-        if (old_node == NULL) break;
-        new_node = apr_pcalloc(pool, sizeof(acmp_node_t));
-        /* ENH: Check alloc succeded */
-        acmp_clone_node_no_state(old_node, new_node);
-        new_node->parent = to;
-        nn2->sibling = new_node;
-        nn2 = new_node;
-        acmp_copy_nodes_recursive(old_node, new_node, pool);
-    }
-}
-
 static inline acmp_node_t *acmp_btree_find(acmp_node_t *node, acmp_utf8_char_t letter) {
     acmp_btree_node_t *bnode = node->btree;
     for (;;) {
@@ -341,7 +309,7 @@ static void acmp_connect_other_matches(ACMP *parser, acmp_node_t *node) {
  * Adds leaves to binary tree, working from sorted array of keyword tree nodes
  */
 static void acmp_add_btree_leaves(acmp_btree_node_t *node, acmp_node_t *nodes[],
-    int pos, int lb, int rb, apr_pool_t *pool) {
+        int pos, int lb, int rb, apr_pool_t *pool) {
 
     int left = 0, right = 0;
     if ((pos - lb) > 1) {
@@ -350,9 +318,9 @@ static void acmp_add_btree_leaves(acmp_btree_node_t *node, acmp_node_t *nodes[],
         /* ENH: Check alloc succeded */
         node->left->node = nodes[left];
         node->left->letter = nodes[left]->letter;
-        #ifdef DEBUG_ACMP
+#ifdef DEBUG_ACMP
         fprintf(stderr, "%lc ->left %lc\n", (wint_t)node->node->letter, (wint_t)node->left->node->letter);
-        #endif
+#endif
     }
     if ((rb - pos) > 1) {
         right = pos + (rb - pos) / 2;
@@ -360,9 +328,9 @@ static void acmp_add_btree_leaves(acmp_btree_node_t *node, acmp_node_t *nodes[],
         /* ENH: Check alloc succeded */
         node->right->node = nodes[right];
         node->right->letter = nodes[right]->letter;
-        #ifdef DEBUG_ACMP
+#ifdef DEBUG_ACMP
         fprintf(stderr, "%lc ->right %lc\n", (wint_t)node->node->letter, (wint_t)node->right->node->letter);
-        #endif
+#endif
     }
     if (node->right != NULL) {
         acmp_add_btree_leaves(node->right, nodes, right, pos, rb, pool);
@@ -436,9 +404,9 @@ static apr_status_t acmp_connect_fail_branches(ACMP *parser) {
     for (child = parser->root_node->child; child != NULL; child = child->sibling) {
         child->fail = parser->root_node;
         *(acmp_node_t **)apr_array_push(arr) = child;
-        #ifdef DEBUG_ACMP
+#ifdef DEBUG_ACMP
         fprintf(stderr, "fail direction: *%s* => *%s*\n", child->text, child->fail->text);
-        #endif
+#endif
     }
 
     for (;;) {
@@ -449,9 +417,9 @@ static apr_status_t acmp_connect_fail_branches(ACMP *parser) {
                 goto_node = acmp_child_for_code(node->parent->fail, node->letter);
                 node->fail = (goto_node != NULL) ? goto_node : parser->root_node;
             }
-            #ifdef DEBUG_ACMP
+#ifdef DEBUG_ACMP
             fprintf(stderr, "fail direction: *%s* => *%s*\n", node->text, node->fail->text);
-            #endif
+#endif
             child = node->child;
             while (child != NULL) {
                 *(acmp_node_t **)apr_array_push(arr2) = child;
@@ -470,29 +438,6 @@ static apr_status_t acmp_connect_fail_branches(ACMP *parser) {
     return APR_SUCCESS;
 }
 
-/**
- * Clears hit count of each node, called from acmp_reset()
- */
-static void acmp_clear_hit_count_recursive(acmp_node_t *node) {
-    for (; node != NULL; node = node->sibling) {
-        node->hit_count = 0;
-        if (node->child != NULL) acmp_clear_hit_count_recursive(node->child);
-    }
-}
-
-/**
- * Called when a match is found
- */
-static void acmp_found(ACMP *parser, acmp_node_t *node) {
-    if (node->callback) {
-        node->callback(parser, node->callback_data,
-            parser->bp_buffer[(parser->char_pos - node->depth - 1) % parser->bp_buff_len],
-            parser->char_pos - node->depth - 1);
-    }
-    node->hit_count++;
-    parser->hit_count++;
-}
-
 /*
  *******************************************************************************
  *******************************************************************************
@@ -516,57 +461,15 @@ ACMP *acmp_create(int flags, apr_pool_t *pool) {
     /* ENH: Check alloc succeded */
     parser->pool = p;
     parser->parent_pool = pool;
-    #ifdef ACMP_USE_UTF8
+#ifdef ACMP_USE_UTF8
     parser->is_utf8 = (flags & ACMP_FLAG_UTF8) == 0 ? 0 : 1;
-    #endif
+#endif
     parser->is_case_sensitive = (flags & ACMP_FLAG_CASE_SENSITIVE) == 0 ? 0 : 1;
     parser->root_node = apr_pcalloc(p, sizeof(acmp_node_t));
     /* ENH: Check alloc succeded */
     return parser;
 }
 
-/**
- * Destroys previously created parser
- */
-void acmp_destroy(ACMP *parser) {
-    /*
-     * All data is kept in parser's pool (including parser struct itself), so
-     * destroying the pool will destroy everything
-     */
-    apr_pool_destroy(parser->pool);
-}
-
-/**
- * Creates parser with same options and same patterns
- * parser - ACMP parser to duplicate
- * pool - parent pool to use, if left as NULL original parser's parent pool is used
- */
-ACMP *acmp_duplicate(ACMP *parser, apr_pool_t *pool) {
-    apr_status_t rc;
-    apr_pool_t *p;
-    ACMP *new_parser;
-
-    if (pool == NULL) pool = parser->parent_pool;
-    rc = apr_pool_create(&p, pool);
-    if (rc != APR_SUCCESS) return NULL;
-
-    new_parser = apr_pcalloc(p, sizeof(ACMP));
-    /* ENH: Check alloc succeded */
-    new_parser->pool = p;
-    new_parser->parent_pool = pool;
-    #ifdef ACMP_USE_UTF8
-    new_parser->is_utf8 = parser->is_utf8;
-    #endif
-    new_parser->is_case_sensitive = parser->is_case_sensitive;
-    new_parser->root_node = apr_pcalloc(p, sizeof(acmp_node_t));
-    /* ENH: Check alloc succeded */
-    new_parser->dict_count = parser->dict_count;
-    new_parser->longest_entry = parser->longest_entry;
-    acmp_copy_nodes_recursive(parser->root_node, new_parser->root_node, new_parser->pool);
-    acmp_prepare(new_parser);
-    return new_parser;
-}
-
 /**
  * Creates fail tree and initializes buffer
  */
@@ -596,7 +499,7 @@ apr_status_t acmp_prepare(ACMP *parser) {
  * len - Length of pattern in characters, if zero string length is used.
  */
 apr_status_t acmp_add_pattern(ACMP *parser, const char *pattern,
-    acmp_callback_t callback, void *data, apr_size_t len)
+        acmp_callback_t callback, void *data, apr_size_t len)
 {
     size_t length, i, j;
     acmp_utf8_char_t *ucs_chars;
@@ -647,122 +550,6 @@ apr_status_t acmp_add_pattern(ACMP *parser, const char *pattern,
     return APR_SUCCESS;
 }
 
-/**
- * Called to process incoming data stream
- * data - ptr to incoming data
- * len - size of data in bytes
- */
-apr_status_t acmp_process(ACMP *parser, const char *data, apr_size_t len) {
-    acmp_node_t *node, *go_to;
-    #ifdef ACMP_USE_UTF8
-    apr_size_t seq_length;
-    #endif
-    const char *end;
-
-    if (parser->is_failtree_done == 0) acmp_prepare(parser);
-
-    node = parser->active_node;
-    end = data + len;
-
-    while (data < end) {
-        acmp_utf8_char_t letter;
-
-        parser->bp_buffer[parser->char_pos % parser->bp_buff_len] = parser->byte_pos;
-        #ifdef ACMP_USE_UTF8
-        if (parser->is_utf8) {
-            if (parser->u8buff_len > 0) {
-                /* Resuming partial utf-8 sequence */
-                seq_length = utf8_seq_len(parser->u8_buff);
-                for (;;) {
-                    parser->u8_buff[parser->u8buff_len++] = *data++;
-                    if (parser->u8buff_len == seq_length) {
-                        parser->u8buff_len = 0;
-                        letter = utf8_decodechar(parser->u8_buff);
-                        parser->byte_pos += seq_length;
-                        parser->char_pos++;
-                        break;
-                    }
-                }
-            } else {
-                /* not resuming partial sequence, reading from the stream */
-                seq_length = utf8_seq_len(data);
-                if ((data + seq_length) > end) {
-                    while (data < end) parser->u8_buff[parser->u8buff_len++] = *data++;
-                    return APR_SUCCESS;
-                } else {
-                    letter = utf8_decodechar(data);
-                    data += seq_length;
-                    parser->byte_pos += seq_length;
-                    parser->char_pos++;
-                }
-            }
-        } else
-        #endif
-        {
-            letter = *data++;
-            parser->byte_pos++;
-            parser->char_pos++;
-        }
-        if (parser->is_case_sensitive == 0) letter = utf8_lcase(letter);
-
-        go_to = NULL;
-        while (go_to == NULL) {
-            acmp_node_t *n2 = acmp_goto(node, letter);
-            go_to = acmp_child_for_code(node, letter);
-            if (n2 != go_to) {
-                n2 = acmp_goto(node, letter);
-            };
-            if (go_to != NULL) {
-                if (go_to->is_last) {
-                    acmp_found(parser, go_to);
-                }
-            }
-            if (node == parser->root_node) break;
-            if (go_to == NULL) node = node->fail;
-        }
-        if (go_to != NULL) node = go_to;
-
-        /* We need to collect other nodes that are last letters of phrase. These
-         *   will be fail node of current node if it has is_last flag set, and
-         *   fail node of that node, recursively down to root node.
-         */
-        go_to = node;
-        if (go_to != parser->root_node) {
-            for (go_to = go_to->o_match; go_to != NULL; go_to = go_to->o_match) {
-                acmp_found(parser, go_to);
-            }
-        }
-    }
-    parser->active_node = node;
-    return parser->hit_count > 0 ? 1 : 0;
-}
-
-/**
- * Resets the state of parser so you can start using it with new set of data.
- *
- * No need to clear buffer since it will be re-initialized at first run of
- * acmp_process
- */
-void acmp_reset(ACMP *parser) {
-    parser->is_active = 0;
-    parser->byte_pos = 0;
-    parser->char_pos = 0;
-    parser->hit_count = 0;
-    parser->u8buff_len = 0;
-    acmp_clear_hit_count_recursive(parser->root_node);
-}
-
-/**
- * Creates an ACMPT struct that will use parser's tree, without duplicating its data
- */
-ACMPT *acmp_duplicate_quick(ACMP *parser, apr_pool_t *pool) {
-    apr_pool_t *p = (pool != NULL) ? pool : parser->pool;
-    ACMPT *dup = apr_pcalloc(p, sizeof(ACMPT));
-    /* ENH: Check alloc succeded */
-    dup->parser = parser;
-    return dup;
-}
-
 /**
  * Process the data using ACMPT to keep state, and ACMPT's parser to keep the tree
  */
