@@ -400,11 +400,6 @@ apr_status_t modsecurity_request_body_to_stream(modsec_rec *msr, const char *buf
 
         stream_input_body = (char *)realloc(msr->stream_input_data, msr->stream_input_length + 1);
 
-        if(stream_input_body == NULL)   {
-            free(msr->stream_input_data);
-            msr->stream_input_data = NULL;
-        }
-
         msr->stream_input_data = (char *)stream_input_body;
     }
 
